@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,6 +8,7 @@
 
 #include "pimcommon_export.h"
 #include <QObject>
+#include <memory>
 namespace PimCommon
 {
 class CustomToolsPlugin;
@@ -25,9 +26,9 @@ public:
     explicit CustomToolsPluginManager(QObject *parent = nullptr);
     ~CustomToolsPluginManager() override;
 
-    Q_REQUIRED_RESULT QVector<PimCommon::CustomToolsPlugin *> pluginsList() const;
+    [[nodiscard]] QList<PimCommon::CustomToolsPlugin *> pluginsList() const;
 
 private:
-    CustomToolsPluginManagerPrivate *const d;
+    std::unique_ptr<CustomToolsPluginManagerPrivate> const d;
 };
 }
