@@ -1,12 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "customtoolswidgetng.h"
 #include "customtoolsplugin.h"
-#include "customtoolspluginmanager.h"
 #include "customtoolsviewinterface.h"
 
 #include <KToggleAction>
@@ -44,7 +43,7 @@ void CustomToolsWidgetNg::addCustomToolViewInterface(PimCommon::CustomToolsViewI
     d->mStackedWidget->addWidget(plugin);
 }
 
-void CustomToolsWidgetNg::initializeView(KActionCollection *ac, const QVector<CustomToolsPlugin *> &localPluginsList)
+void CustomToolsWidgetNg::initializeView(KActionCollection *ac, const QList<CustomToolsPlugin *> &localPluginsList)
 {
     for (CustomToolsPlugin *plugin : localPluginsList) {
         PimCommon::CustomToolsViewInterface *localCreateView = plugin->createView(ac, this);
@@ -100,3 +99,5 @@ void CustomToolsWidgetNg::setText(const QString &text)
         }
     }
 }
+
+#include "moc_customtoolswidgetng.cpp"
