@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -26,11 +26,20 @@ class PIMCOMMON_EXPORT ShareServiceUrlManager : public QObject
 public:
     explicit ShareServiceUrlManager(QObject *parent = nullptr);
     ~ShareServiceUrlManager() override;
-    enum ServiceType { Fbook = 0, Twitter, MailTo, LinkedIn, Evernote, Pocket, LiveJournal, ServiceEndType };
+    enum ServiceType {
+        Fbook = 0,
+        Twitter,
+        MailTo,
+        LinkedIn,
+        Evernote,
+        Pocket,
+        LiveJournal,
+        ServiceEndType,
+    };
 
-    Q_REQUIRED_RESULT KActionMenu *menu() const;
+    [[nodiscard]] KActionMenu *menu() const;
 
-    Q_REQUIRED_RESULT QUrl generateServiceUrl(const QString &link, const QString &title, ServiceType type);
+    [[nodiscard]] QUrl generateServiceUrl(const QString &link, const QString &title, ServiceType type);
 
     void openUrl(const QUrl &url);
 
