@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ CustomTreeView::CustomTreeView(QWidget *parent)
 {
 }
 
-CustomTreeView::~CustomTreeView()
-{
-}
+CustomTreeView::~CustomTreeView() = default;
 
 void CustomTreeView::changeEvent(QEvent *event)
 {
@@ -84,3 +82,5 @@ void CustomTreeView::paintEvent(QPaintEvent *event)
         QTreeWidget::paintEvent(event);
     }
 }
+
+#include "moc_customtreeview.cpp"
