@@ -5,15 +5,9 @@
 */
 
 #include "purposemenuwidget.h"
-#include "purpose_version.h"
 #include <KLocalizedString>
-#include <KMessageBox>
 #include <Purpose/AlternativesModel>
-#if PURPOSE_VERSION < QT_VERSION_CHECK(5, 104, 0)
-#include <PurposeWidgets/Menu>
-#else
 #include <Purpose/Menu>
-#endif
 #include <QJsonArray>
 #include <QTemporaryFile>
 #include <QUrl>
@@ -56,17 +50,15 @@ void PurposeMenuWidget::slotInitializeShareMenu()
 void PurposeMenuWidget::slotShareActionFinished(const QJsonObject &output, int error, const QString &message)
 {
     if (error) {
-        KMessageBox::error(mParentWidget, i18n("There was a problem sharing the document: %1", message), i18n("Share"));
+        Q_EMIT shareError(i18n("There was a problem sharing the document: %1", message));
     } else {
         const QString url = output[QLatin1String("url")].toString();
         if (url.isEmpty()) {
-            KMessageBox::information(mParentWidget, i18n("File was shared."));
+            Q_EMIT shareSuccess(i18n("File was shared."));
         } else {
-            KMessageBox::information(mParentWidget,
-                                     i18n("<qt>You can find the new request at:<br /><a href='%1'>%1</a> </qt>", url),
-                                     QString(),
-                                     QString(),
-                                     KMessageBox::AllowLink);
+            Q_EMIT shareSuccess(i18n("<qt>You can find the new request at:<br /><a href='%1'>%1</a> </qt>", url));
         }
     }
 }
+
+#include "moc_purposemenuwidget.cpp"
