@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,9 +19,7 @@ ImapAclAttributeTest::ImapAclAttributeTest(QObject *parent)
 {
 }
 
-ImapAclAttributeTest::~ImapAclAttributeTest()
-{
-}
+ImapAclAttributeTest::~ImapAclAttributeTest() = default;
 
 void ImapAclAttributeTest::shouldHaveDefaultValue()
 {
@@ -241,3 +239,5 @@ void ImapAclAttributeTest::testOldRights()
 }
 
 QTEST_MAIN(ImapAclAttributeTest)
+
+#include "moc_imapaclattributetest.cpp"
