@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,16 +18,14 @@ public:
     explicit CollectionAclWidget(QWidget *parent = nullptr);
     ~CollectionAclWidget() override;
 
-    Q_REQUIRED_RESULT PimCommon::AclManager *aclManager() const;
-    Q_REQUIRED_RESULT bool recursive() const;
+    [[nodiscard]] PimCommon::AclManager *aclManager() const;
+    [[nodiscard]] bool recursive() const;
     void setEnableRecursiveCheckBox(bool enable);
 
-private Q_SLOTS:
+private:
     void slotRecursivePermissionChanged();
     void slotCollectionCanBeAdministrated(bool b);
-
-private:
-    PimCommon::AclManager *mAclManager = nullptr;
-    QCheckBox *mRecursiveChk = nullptr;
+    PimCommon::AclManager *const mAclManager;
+    QCheckBox *const mRecursiveChk;
 };
 }
