@@ -34,27 +34,34 @@ void AddresseeLineEditBaloo::setBalooCompletionSource(int value)
 
 QStringList AddresseeLineEditBaloo::balooBlackList() const
 {
-    return mBalooBlackList;
+    return mBalooCompletionEmail->balooCompletionEmailInfo().mBlackList;
 }
 
 QStringList AddresseeLineEditBaloo::domainExcludeList() const
 {
-    return mDomainExcludeList;
+    return mBalooCompletionEmail->balooCompletionEmailInfo().mExcludeDomains;
 }
 
 void AddresseeLineEditBaloo::loadBalooBlackList()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kpimbalooblacklist"));
     config->reparseConfiguration();
-    KConfigGroup group(config, "AddressLineEdit");
-    mBalooBlackList = group.readEntry("BalooBackList", QStringList());
-    mDomainExcludeList = group.readEntry("ExcludeDomain", QStringList());
-    mBalooCompletionEmail->setBlackList(mBalooBlackList);
-    mBalooCompletionEmail->setExcludeDomain(mDomainExcludeList);
+    KConfigGroup group(config, QStringLiteral("AddressLineEdit"));
+    PimCommon::BalooCompletionEmail::BalooCompletionEmailInfo info;
+    const QStringList balooBlackList = group.readEntry("BalooBackList", QStringList());
+    const QStringList domainExcludeList = group.readEntry("ExcludeDomain", QStringList());
+    const QStringList lstExcludeEmailsRegularExpressions = group.readEntry("ExcludeEmailsRegexp", QStringList());
+
+    info.mExcludeEmailsRegularExpressions = lstExcludeEmailsRegularExpressions;
+    info.mBlackList = balooBlackList;
+    info.mExcludeDomains = domainExcludeList;
+    mBalooCompletionEmail->setBalooCompletionEmailInfo(info);
 }
 
 QStringList AddresseeLineEditBaloo::cleanupEmailList(const QStringList &inputList)
 {
-    mBalooCompletionEmail->setEmailList(inputList);
+    PimCommon::BalooCompletionEmail::BalooCompletionEmailInfo info = mBalooCompletionEmail->balooCompletionEmailInfo();
+    info.mListEmail = inputList;
+    mBalooCompletionEmail->setBalooCompletionEmailInfo(info);
     return mBalooCompletionEmail->cleanupEmailList();
 }
