@@ -5,7 +5,7 @@
 */
 
 #include "addresseelineeditutiltest.h"
-#include "../addresslineedit/addresseelineeditutil.h"
+#include "addressline/addresslineedit/addresseelineeditutil.h"
 #include <QTest>
 
 AddresseeLineEditUtilTest::AddresseeLineEditUtilTest(QObject *parent)
@@ -51,3 +51,5 @@ void AddresseeLineEditUtilTest::shouldAdaptPasteMails()
 }
 
 QTEST_MAIN(AddresseeLineEditUtilTest)
+
+#include "moc_addresseelineeditutiltest.cpp"
