@@ -20,6 +20,8 @@ void BlackListBalooEmailListTest::shouldHaveDefaultValue()
 {
     PimCommon::BlackListBalooEmailList blackList;
     QVERIFY(blackList.count() == 0);
+    QVERIFY(blackList.isSortingEnabled());
+    QCOMPARE(blackList.selectionMode(), QAbstractItemView::ExtendedSelection);
 }
 
 void BlackListBalooEmailListTest::shouldFillListEmail()
@@ -81,14 +83,14 @@ void BlackListBalooEmailListTest::shouldNotAddDuplicateEmails()
 void BlackListBalooEmailListTest::shouldExcludeDomain()
 {
     PimCommon::BlackListBalooEmailList blackList;
-    blackList.setExcludeDomain(QStringList() << QStringLiteral("kde.org") << QStringLiteral("toto.fr"));
+    blackList.setExcludeDomains(QStringList() << QStringLiteral("kde.org") << QStringLiteral("toto.fr"));
     QStringList emails = QStringList() << QStringLiteral("foo@kde.org") << QStringLiteral("bli@fr.fr") << QStringLiteral("bli@toto.fr");
     blackList.setEmailBlackList(emails);
     QCOMPARE(blackList.setEmailFound(emails), 1);
 
     QCOMPARE(blackList.count(), 1);
 
-    blackList.setExcludeDomain(QStringList() << QStringLiteral("kde.org") << QStringLiteral("toto.fr"));
+    blackList.setExcludeDomains(QStringList() << QStringLiteral("kde.org") << QStringLiteral("toto.fr"));
     emails = QStringList() << QStringLiteral("<foo@kde.org>") << QStringLiteral("bli@fr.fr") << QStringLiteral("bli@toto.fr");
     blackList.setEmailBlackList(emails);
     QCOMPARE(blackList.setEmailFound(emails), 1);
@@ -114,3 +116,5 @@ void BlackListBalooEmailListTest::shouldAvoidSameEmailWithDisplayNameOrNot()
 }
 
 QTEST_MAIN(BlackListBalooEmailListTest)
+
+#include "moc_blacklistbalooemaillisttest.cpp"
