@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -19,7 +19,7 @@ public:
     explicit BlackListBalooEmailSearchJob(QObject *parent = nullptr);
     ~BlackListBalooEmailSearchJob() override;
 
-    Q_REQUIRED_RESULT bool start();
+    [[nodiscard]] bool start();
 
     void setSearchEmail(const QString &searchEmail);
 
@@ -33,4 +33,3 @@ private:
     int mLimit = 500;
 };
 }
-
