@@ -7,11 +7,12 @@
 
 #include "completionconfiguredialog.h"
 #include <KConfigGroup>
-#include <KLDAP/LdapClientSearch>
+#include <KLDAPWidgets/LdapClientSearch>
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <KWindowConfig>
 #include <QDialogButtonBox>
+#include <QPushButton>
 #include <QTabWidget>
 #include <QVBoxLayout>
 #include <QWindow>
@@ -66,9 +67,10 @@ CompletionConfigureDialog::CompletionConfigureDialog(QWidget *parent)
     d->mTabWidget->addTab(d->mBlackListBalooWidget, i18n("Blacklist Email Address"));
 #endif
 
-    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Apply | QDialogButtonBox::Cancel, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
-    connect(buttonBox, &QDialogButtonBox::accepted, this, &CompletionConfigureDialog::slotSave);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &CompletionConfigureDialog::slotSaveAndClose);
+    connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &CompletionConfigureDialog::slotSave);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
     mainLayout->addWidget(buttonBox);
     readConfig();
@@ -83,14 +85,14 @@ void CompletionConfigureDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 400));
-    KConfigGroup group(KSharedConfig::openStateConfig(), myCompletionConfigureDialogGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myCompletionConfigureDialogGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void CompletionConfigureDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myCompletionConfigureDialogGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myCompletionConfigureDialogGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 
@@ -99,7 +101,7 @@ void CompletionConfigureDialog::setRecentAddresses(const QStringList &lst)
     d->mRecentaddressWidget->setAddresses(lst);
 }
 
-void CompletionConfigureDialog::setLdapClientSearch(KLDAP::LdapClientSearch *ldapSearch)
+void CompletionConfigureDialog::setLdapClientSearch(KLDAPWidgets::LdapClientSearch *ldapSearch)
 {
     d->mCompletionOrderWidget->setLdapClientSearch(ldapSearch);
 }
@@ -122,13 +124,18 @@ void CompletionConfigureDialog::storeAddresses(KConfig *config)
     d->mRecentaddressWidget->storeAddresses(config);
 }
 
+void CompletionConfigureDialog::slotSaveAndClose()
+{
+    slotSave();
+    accept();
+}
+
 void CompletionConfigureDialog::slotSave()
 {
 #if !DISABLE_AKONADI_SEARCH
     d->mBlackListBalooWidget->save();
 #endif
     d->mCompletionOrderWidget->save();
-    accept();
 }
 
 void CompletionConfigureDialog::setEmailBlackList(const QStringList &lst)
@@ -137,3 +144,5 @@ void CompletionConfigureDialog::setEmailBlackList(const QStringList &lst)
     d->mBlackListBalooWidget->setEmailBlackList(lst);
 #endif
 }
+
+#include "moc_completionconfiguredialog.cpp"
