@@ -9,22 +9,25 @@
 
 #include "completionordereditor.h"
 #include "completionorderwidget.h"
-#include <KLDAP/LdapClient>
-#include <KLDAP/LdapClientSearch>
+#include <KLDAPWidgets/LdapClient>
+#include <KLDAPWidgets/LdapClientSearch>
 
-#include <KContacts/Addressee>
-#include <KContacts/ContactGroup>
-#include <kldap/ldapserver.h>
+#include <kldapcore/ldapserver.h>
 
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <QWindow>
 
 using namespace PimCommon;
-
+namespace
+{
+static const char myCompletionOrderEditorGroupName[] = "CompletionOrderEditor";
+}
 class PimCommon::CompletionOrderEditorPrivate
 {
 public:
@@ -33,7 +36,7 @@ public:
     CompletionOrderWidget *mCompletionOrderWidget = nullptr;
 };
 
-CompletionOrderEditor::CompletionOrderEditor(KLDAP::LdapClientSearch *ldapSearch, QWidget *parent)
+CompletionOrderEditor::CompletionOrderEditor(KLDAPWidgets::LdapClientSearch *ldapSearch, QWidget *parent)
     : QDialog(parent)
     , d(new PimCommon::CompletionOrderEditorPrivate)
 {
@@ -67,18 +70,17 @@ CompletionOrderEditor::~CompletionOrderEditor()
 
 void CompletionOrderEditor::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "CompletionOrderEditor");
-    const QSize size = group.readEntry("Size", QSize(600, 400));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(600, 400));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myCompletionOrderEditorGroupName));
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void CompletionOrderEditor::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "CompletionOrderEditor");
-    group.writeEntry("Size", size());
-    group.sync();
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myCompletionOrderEditorGroupName));
+    KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 
 void CompletionOrderEditor::slotOk()
@@ -86,3 +88,5 @@ void CompletionOrderEditor::slotOk()
     d->mCompletionOrderWidget->save();
     accept();
 }
+
+#include "moc_completionordereditor.cpp"
