@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,11 +13,11 @@ AddressessLineEditAbstractPlugin::AddressessLineEditAbstractPlugin(QObject *pare
 {
 }
 
-AddressessLineEditAbstractPlugin::~AddressessLineEditAbstractPlugin()
-{
-}
+AddressessLineEditAbstractPlugin::~AddressessLineEditAbstractPlugin() = default;
 
 void AddressessLineEditAbstractPlugin::setLineEdit(AddresseeLineEdit *linedit)
 {
     mLinedit = linedit;
 }
+
+#include "moc_addressesslineeditabstractplugin.cpp"
