@@ -16,12 +16,13 @@
 
 #include <QKeyEvent>
 #include <QListWidget>
+#include <QMenu>
 #include <QShortcut>
 #include <QToolButton>
 #include <QVBoxLayout>
 
-#include <Libkdepim/LineEditCatchReturnKey>
-#include <PimCommon/EmailValidator>
+#include <KEmailValidator>
+#include <KLineEditEventHandler>
 
 using namespace PimCommon;
 RecentAddressWidget::RecentAddressWidget(QWidget *parent)
@@ -37,15 +38,16 @@ RecentAddressWidget::RecentAddressWidget(QWidget *parent)
     layout->addLayout(lineLayout);
 
     mLineEdit->setObjectName(QStringLiteral("line_edit"));
-    new KPIM::LineEditCatchReturnKey(mLineEdit, this);
+    KLineEditEventHandler::catchReturnKey(mLineEdit);
     mLineEdit->installEventFilter(this);
     mLineEdit->setClearButtonEnabled(true);
-    mLineEdit->setValidator(new PimCommon::EmailValidator(this));
+    mLineEdit->setValidator(new KEmailValidator(this));
+    mLineEdit->setPlaceholderText(i18n("New email..."));
     connect(mLineEdit, &QLineEdit::returnPressed, this, &RecentAddressWidget::slotAddItem);
 
     lineLayout->addWidget(mLineEdit);
 
-    mNewButton->setToolTip(i18n("Add"));
+    mNewButton->setToolTip(i18n("Add Email"));
     mNewButton->setObjectName(QStringLiteral("new_button"));
     mNewButton->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     mNewButton->setEnabled(false);
@@ -67,7 +69,9 @@ RecentAddressWidget::RecentAddressWidget(QWidget *parent)
     mListView->setObjectName(QStringLiteral("list_view"));
     mListView->setSelectionMode(QAbstractItemView::ExtendedSelection);
     mListView->setSortingEnabled(true);
+    mListView->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(mListView, &QListWidget::itemSelectionChanged, this, &RecentAddressWidget::updateButtonState);
+    connect(mListView, &QListWidget::customContextMenuRequested, this, &RecentAddressWidget::slotCustomContextMenuRequested);
     layout->addWidget(mListView);
     mDirty = false;
 }
@@ -79,6 +83,23 @@ void RecentAddressWidget::slotUpdateAddButton(const QString &str)
     mNewButton->setEnabled(!str.trimmed().isEmpty());
 }
 
+void RecentAddressWidget::slotCustomContextMenuRequested(const QPoint &pos)
+{
+    const QList<QListWidgetItem *> selectedItems = mListView->selectedItems();
+    if (selectedItems.isEmpty()) {
+        return;
+    }
+    QListWidgetItem *item = mListView->itemAt(pos);
+    if (item) {
+        QMenu menu(this);
+        menu.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")),
+                       i18np("Remove Email", "Remove Emails", selectedItems.count()),
+                       this,
+                       &RecentAddressWidget::slotRemoveItem);
+        menu.exec(QCursor::pos());
+    }
+}
+
 void RecentAddressWidget::slotAddItem()
 {
     const QString newEmail = mLineEdit->text();
@@ -109,7 +130,7 @@ void RecentAddressWidget::slotRemoveItem()
     const int answer =
         KMessageBox::questionTwoActions(this,
                                         i18np("Do you want to remove this email address?", "Do you want to remove %1 email addresses?", selectedItems.count()),
-                                        i18n("Remove"),
+                                        i18nc("@title:window", "Remove"),
                                         KStandardGuiItem::remove(),
                                         KStandardGuiItem::cancel());
     if (answer == KMessageBox::ButtonCode::PrimaryAction) {
@@ -161,3 +182,5 @@ bool RecentAddressWidget::wasChanged() const
 {
     return mDirty;
 }
+
+#include "moc_recentaddresswidget.cpp"
