@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -33,21 +33,20 @@ public:
     explicit CheckedCollectionWidget(const QString &mimetype, QWidget *parent = nullptr);
     ~CheckedCollectionWidget() override;
 
-    Q_REQUIRED_RESULT Akonadi::EntityTreeModel *entityTreeModel() const;
+    [[nodiscard]] Akonadi::EntityTreeModel *entityTreeModel() const;
 
-    Q_REQUIRED_RESULT QTreeView *folderTreeView() const;
+    [[nodiscard]] QTreeView *folderTreeView() const;
 
-    Q_REQUIRED_RESULT QItemSelectionModel *selectionModel() const;
+    [[nodiscard]] QItemSelectionModel *selectionModel() const;
 
-    Q_REQUIRED_RESULT KCheckableProxyModel *checkableProxy() const;
+    [[nodiscard]] KCheckableProxyModel *checkableProxy() const;
 
 Q_SIGNALS:
     void collectionAdded(const Akonadi::Collection &, const Akonadi::Collection &);
     void collectionRemoved(const Akonadi::Collection &);
 
 private:
-    void slotSetCollectionFilter(const QString &filter);
+    PIMCOMMONAKONADI_NO_EXPORT void slotSetCollectionFilter(const QString &filter);
     std::unique_ptr<CheckedCollectionWidgetPrivate> const d;
 };
 }
-
