@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,7 +21,7 @@ public:
     explicit SelectMultiCollectionWidget(const QString &mimetype, QWidget *parent = nullptr);
     ~SelectMultiCollectionWidget() override;
 
-    Q_REQUIRED_RESULT QVector<Akonadi::Collection> selectedCollection(const QModelIndex &parent = QModelIndex()) const;
+    [[nodiscard]] QList<Akonadi::Collection> selectedCollection(const QModelIndex &parent = QModelIndex()) const;
 
 private:
     void slotCollectionsTreeFetched();
@@ -31,4 +31,3 @@ private:
     QList<Akonadi::Collection::Id> mListCollection;
 };
 }
-
